Hypothesiser
============

.. automodule:: stonesoup.hypothesiser
    :no-members:

.. automodule:: stonesoup.hypothesiser.base
    :show-inheritance:

Distance
--------

.. automodule:: stonesoup.hypothesiser.distance
    :show-inheritance:

Probability
-----------

.. automodule:: stonesoup.hypothesiser.probability
    :show-inheritance:

